//---------------------------------------------------------------------------
// TestAggregatedMortality
//---------------------------------------------------------------------------
#if !defined(TestAggregatedMortality_H)
  #define TestAggregatedMortality_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

class clSimManager;

/**
* Tests the clAggregatedMortality class.
*/
class clTestAggregatedMortality : public CppUnit::TestFixture {

  public:

  /**
  * Assembles all other testing functions into one test.
  */
  void TestAggregatedMortality();

  protected:
  
  /**
  * Tests error processing.
  */
  void TestErrorProcessing(clSimManager *p_oSimManager);

  /**
  * Tests normal processing Run 1.  WriteXMLFile1() writes the parameter file.
  * This run tests getting proportions right, and general aggregation.
  * @param p_oSimManager Sim Manager object to run our test run.
  */
  void TestNormalProcessingRun1(clSimManager *p_oSimManager);
  
  /**
  * Tests normal processing Run 2.  WriteXMLFile2() writes the parameter file.
  * Tests aggregation across multiple grid cells. 
  * @param p_oSimManager Sim Manager object to run our test run.
  */
  void TestNormalProcessingRun2(clSimManager *p_oSimManager);
  
  /**
  * Tests normal processing Run 3.  WriteXMLFile3() writes the parameter file.
  * Tests that only trees to which the behavior applies are cut.
  * @param p_oSimManager Sim Manager object to run our test run.
  */
  void TestNormalProcessingRun3(clSimManager *p_oSimManager);
  
  /**
  * Tests normal processing Run 4.  WriteXMLFile4() writes the parameter file.
  * Tests correct aggregation across longer distances.
  * @param p_oSimManager Sim Manager object to run our test run.
  */
  void TestNormalProcessingRun4(clSimManager *p_oSimManager);
  
  /**
  * Tests normal processing Run 5.  WriteXMLFile5() writes the parameter file.
  * Tests that behavior acts correctly when the clumping number is 1.
  *
  * @param p_oSimManager Sim Manager object to run our test run.
  */
  void TestNormalProcessingRun5(clSimManager *p_oSimManager);
  
  /**
  * Tests normal processing Run 6.  WriteXMLFile6() writes the parameter file.
  * Tests that return intervals are correctly calculated.
  *
  * @param p_oSimManager Sim Manager object to run our test run.
  */
  void TestNormalProcessingRun6(clSimManager *p_oSimManager);
  
  /**
  * Writes the parameter file for TestNormalProcessing1().
  * @return File name of the freshly written parameter file.
  */
  char *WriteXMLFile1();

  /**
  * Writes the parameter file for TestNormalProcessing2().
  * @return File name of the freshly written parameter file.
  */
  char *WriteXMLFile2();
  
  /**
  * Writes the parameter file for TestNormalProcessing3().
  * @return File name of the freshly written parameter file.
  */
  char *WriteXMLFile3();
  
  /**
  * Writes the parameter file for TestNormalProcessing4().
  * @return File name of the freshly written parameter file.
  */
  char *WriteXMLFile4();
  
  /**
  * Writes the parameter file for TestNormalProcessing5().
  * @return File name of the freshly written parameter file.
  */
  char *WriteXMLFile5();
  
  /**
  * Writes the parameter file for TestNormalProcessing6().
  * @return File name of the freshly written parameter file.
  */
  char *WriteXMLFile6();
  
  /**
  * Writes an error file where the value for amount to cut is not between 
  * 0 and 1.
  * @return File name of the freshly written parameter file.
  */
  char* WriteXMLErrorFile1();

  /**
  * Writes an error file where the return interval is less than 0.
  * @return File name of the freshly written parameter file.
  */
  char* WriteXMLErrorFile2();
  /**
  * Writes common portions of the test parameter files.  Starts with
  * &lt;randomSeed&gt; and ends with &lt;/allometry&gt;.
  * @param oOut File stream to write to.
  */
  void WriteCommonStuff(std::fstream &oOut);
};
//---------------------------------------------------------------------------
#endif //TestAggregatedMortality_H
