//---------------------------------------------------------------------------
// TestResourceMortality
//---------------------------------------------------------------------------
#if !defined(TestResourceMortality_H)
  #define TestResourceMortality_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>

/**
* Tests the clResourceMortality class.
* @author Lora E. Murphy
*/
class clTestResourceMortality : public CppUnit::TestFixture
{
  public:

  /**
  * Tests the growth-and-resource mortality class.
  *
  * First run: WriteXMLFile1() creates the parameter file.  The file has the
  * following characteristics:
  * <ul>
  * <li>Timestep length of 1 year.</li>
  * <li>3 species: Species 1, Species 2, Species 3 (Species 2 isn't used).</li>
  * <li>Growth and resource mortality applied to saplings and adults of both
  * species.</li>
  * <li>The resource grid has specified values for 4 cells.</li>
  * </ul>
  * The function does the following:
  * <ol>
  * <li>1000 trees are created of each species for both saplings and
  * adults.
  * <ul>
  * <li>Saplings of species 1 all get a value of 0 in their "lgm" data member
  * and 0 for their resource level.</li>
  * <li>Saplings of Species 3 all get a value of 0 in their "lgm" data member
  * and 1.2 for their resource level.</li>
  * <li>Adults of Species 1 all get a value of 4 in their "lgm" data member
  * and 0 for their resource level.</li>
  * <li>Adults of Species 3 all get a value of 25.1 in their "lgm" data member
  * and 0.01 for their resource level.</li>
  * </ul></li>
  * <li> The model is run for 1 timestep.</li>
  * <li> The remaining trees of each tree type and species are counted.</li>
  * <li> The counts are compared to expected results, give or take 5% (or
  * greater tolerance at lower numbers).</li>
  * </ol>
  *
  * Second run:
  * WriteXMLFile2() creates the parameter file.  The file has the following
  * characteristics:
  * <ul>
  * <li>Timestep length of 5 years.
  * <li>3 species: Species 1, Species 2, Species 3 (Species 2 isn't used).</li>
  * <li>Growth and resource mortality applied to saplings and adults of both
  * species.</li>
  * <li>The resource grid has specified values for 4 cells.</li>
  * </ul>
  * The function does the following:
  * <ol>
  * <li>1000 trees are created of each species for both saplings and
  * adults.
  * <ul>
  * <li>Saplings of species 1 all get a value of 0 in their "lgm" data member
  * and 0 for their resource level.</li>
  * <li>Saplings of Species 3 all get a value of 0 in their "lgm" data member
  * and 1.2 for their resource level.</li>
  * <li>Adults of Species 1 all get a value of 4 in their "lgm" data member
  * and 0 for their resource level.</li>
  * <li>Adults of Species 3 all get a value of 25.1 in their "lgm" data member
  * and 0.01 for their resource level.</li>
  * </ul></li>
  * <li> The model is run for 1 timestep.</li>
  * <li> The remaining trees of each tree type and species are counted.</li>
  * <li> The counts are compared to expected results, give or take 5% (or
  * greater tolerance at lower numbers).</li>
  * </ol>
  */
  void TestResourceMortality();

  protected:

  /**
  * Writes a parameter file with the specifications given for
  * TestMortality(), run 1.
  * @return Filename written.
  */
  char * WriteXMLFile1();

  /**
  * Writes a parameter file with the specifications given for
  * TestMortality(), run 2.
  * @return Filename written.
  */
  char * WriteXMLFile2();

};
//---------------------------------------------------------------------------
#endif // TestResourceMortality_H
