//---------------------------------------------------------------------------
// TestVolumeCalculator
//---------------------------------------------------------------------------
#if !defined(TestVolumeCalculator_H)
  #define TestVolumeCalculator_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>
#include <cppunit/TestSuite.h>

class clSimManager;

/**
* Tests the class clVolumeCalculator.
*/
class clTestVolumeCalculator : public CppUnit::TestFixture {

  public:

  /**
  * Performs all the tests from one function.
  */
  void TestVolumeCalculator();

  protected:

  /**
  * Tests normal processing.  It does this by calling NormalRun1(),
  * NormalRun2(), NormalRun3(), NormalRun4(), and NormalRun5().
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void TestNormalProcessing(clSimManager *p_oSimManager);

  /**
  * Tests error processing.  This uses WriteXMLErrorFile1(),
  * WriteXMLErrorFile2(), WriteXMLErrorFile3(), and WriteXMLErrorFile4() to
  * introduce errors and makes sure that they are caught.
  */
  void TestErrorProcessing(clSimManager *p_oSimManager);

  /**
  * Performs the first normal processing run.  WriteXMLFile1() does setup.
  * Five trees are created of two species.  Then the run is allowed to proceed
  * and their volumes are checked.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void NormalRun1(clSimManager *p_oSimManager);

  /**
  * Performs the second normal processing run.  WriteXMLFile2() does setup.
  * Two trees are created of two species.  Then the run is allowed to proceed
  * and their volumes are checked.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void NormalRun2(clSimManager *p_oSimManager);

  /**
  * Performs the third normal processing run.  WriteXMLFile3() does setup.
  * One tree is created.  Then the run is allowed to proceed and its volume
  * is checked.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void NormalRun3(clSimManager *p_oSimManager);

  /**
  * Performs the fourth normal processing run.  WriteXMLFile4() does setup.
  * Four trees are created of two species.  Then the run is allowed to proceed
  * and their volumes are checked.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void NormalRun4(clSimManager *p_oSimManager);

  /**
  * Performs the fifth normal processing run.  WriteXMLFile5() does setup.
  * Two trees are created of two species.  Then the run is allowed to proceed
  * and their volumes are checked.
  * @param p_oSimManager Sim Manager object to call for runs.
  */
  void NormalRun5(clSimManager *p_oSimManager);

  /**
  * Writes the parameter file for NormalRun1().
  * @return Filename written.
  */
  char* WriteXMLFile1();

  /**
  * Writes the parameter file for NormalRun2().
  * @return Filename written.
  */
  char* WriteXMLFile2();

  /**
  * Writes the parameter file for NormalRun3().
  * @return Filename written.
  */
  char* WriteXMLFile3();

  /**
  * Writes the parameter file for NormalRun4().
  * @return Filename written.
  */
  char* WriteXMLFile4();

  /**
  * Writes the parameter file for NormalRun5().
  * @return Filename written.
  */
  char* WriteXMLFile5();

  /**
  * Writes an error file where the stump height is less than 0.
  */
  char* WriteXMLErrorFile1();

  /**
  * Writes an error file where the minimum usable diameter is less than 0.
  */
  char* WriteXMLErrorFile2();

  /**
  * Writes an error file where the segment length is less than 0.
  */
  char* WriteXMLErrorFile3();

  /**
  * Writes an error file where the volume behavior is applied to seedlings.
  */
  char* WriteXMLErrorFile4();

  /**
  * Writes common portions of the test parameter files (tree pop, plot, etc).
  * @param oOut File stream to write to.
  */
  void WriteCommonStuff(std::fstream &oOut);


};
//---------------------------------------------------------------------------
#endif // TestVolumeCalculator_H
